@@ -53,7 +53,7 @@ def create_job_export_file(job_id, raw, worker_data):
 
     data = {
         'data': {
-            "type": "export_files",
+            "type": "exportFiles",
             "attributes": {
                 "jobId": f'{job_id}',
                 "type": 'raw' if raw else 'target',
