@@ -1,4 +1,5 @@
 import argparse
+import logging
 from datetime import datetime
 from django.utils.text import slugify
 from tasq_cli import jobs, export_files
@@ -13,6 +14,7 @@ def main():
     parser.add_argument('-d', '--dataset-name', action='store', help='set current dataset name')
     parser.add_argument('-c', '--client-id', action='store', help='override client id')
     parser.add_argument('-b', '--bucket-name', action='store', help='override bucket name')
+    parser.add_argument('--silent', action='store_true', help='An opt-out from logging')
 
     # NOTE
     # in Python 3.8 you can pass an additional argument to add_subparsers
@@ -70,7 +72,11 @@ def main():
     get_export_file.add_argument('export_file_id', help='the export file id')
 
     args = parser.parse_args()
-    logger = settings.get_logger()
+    if not args.silent:
+        logger = settings.get_logger()
+    else:
+        logger = logging.getLogger('dummy')
+        logger.addHandler(logging.NullHandler())
 
     logger.info(f'Tasq CLI {settings.VERSION}')
 
