@@ -27,7 +27,7 @@ def create_project_export_file(project_id, raw, worker_data):
 
     data = {
         'data': {
-            "type": "export_files",
+            "type": "exportFiles",
             "attributes": {
                 "projectId": f'{project_id}',
                 "type": 'raw' if raw else 'target',
