@@ -45,7 +45,7 @@ def add_tag(project_resource_id, current_tags, tag, batch_id, step_id):
     payload = {
                 "data": {
                     "id": str(project_resource_id),
-                    "type": "project_resources",
+                    "type": "projectResources",
                     "attributes": {
                         "tagNames": list((*current_tags, tag)),
                         "batchId": str(batch_id),
